@@ -1,4 +1,4 @@
 pub mod base;
-pub mod extra;
+pub mod components;
 
 pub use base::Config;
