@@ -1,13 +1,13 @@
 use crate::fmt::date::{Day, Meridiem, Month};
 use crate::fmt::{Format, Iconize};
-use chrono::Weekday;
 use std::fmt;
+use time::Weekday;
 
 #[derive(Debug, PartialEq)]
 pub struct DateFormatter {
-    hour: u32,
-    minute: u32,
-    day: u32,
+    hour: u8,
+    minute: u8,
+    day: u8,
     month: Month,
     railway: bool,
     weekday: Day,
@@ -27,36 +27,37 @@ impl DateFormatter {
         }
     }
 
-    pub fn set_hour(&mut self, hour: u32) {
-        self.hour = hour;
+    pub fn set_railway(&mut self, railway: bool) {
+        self.railway = railway;
     }
 
-    #[cfg(test)]
-    pub fn use_railway(&mut self) {
-        self.railway = true;
+    pub fn set_hour(&mut self, hour: u8) {
+        if self.railway {
+            self.hour = hour;
+        } else if hour <= 12 {
+            self.hour = hour;
+            self.meridiem = Meridiem::Ante;
+        } else if hour > 12 {
+            self.hour = hour - 12;
+            self.meridiem = Meridiem::Post;
+        }
     }
 
-    pub fn set_minute(&mut self, minute: u32) {
+    pub fn set_minute(&mut self, minute: u8) {
         self.minute = minute;
     }
 
-    pub fn set_day(&mut self, day: u32) {
+    pub fn set_day(&mut self, day: u8) {
         self.day = day;
     }
 
-    pub fn set_month(&mut self, month: u32) {
+    pub fn set_month(&mut self, month: time::Month) {
         self.month = month.into();
     }
 
     pub fn set_weekday(&mut self, weekday: Weekday) {
         self.weekday = weekday.into();
     }
-
-    pub fn set_meridiem(&mut self, pm: bool) {
-        if pm {
-            self.meridiem = Meridiem::Post;
-        }
-    }
 }
 
 impl Iconize for DateFormatter {
@@ -124,18 +125,17 @@ mod tests {
     #[test]
     fn display() {
         let mut fmt = DateFormatter::new();
-        fmt.set_weekday(Weekday::Sat);
-        fmt.set_meridiem(true);
+        fmt.set_weekday(Weekday::Saturday);
         fmt.set_day(1);
-        fmt.set_month(8);
-        fmt.set_hour(2);
+        fmt.set_month(time::Month::August);
+        fmt.set_hour(14);
         fmt.set_minute(37);
         assert_eq!(fmt.to_string(), "Sat, Aug 01 at 02:37 PM".to_owned());
 
-        fmt.use_railway();
-        fmt.set_weekday(Weekday::Mon);
+        fmt.set_railway(true);
+        fmt.set_weekday(Weekday::Monday);
         fmt.set_day(13);
-        fmt.set_month(9);
+        fmt.set_month(time::Month::September);
         fmt.set_hour(16);
         fmt.set_minute(12);
         assert_eq!(fmt.to_string(), "Mon, Sep 13 at 16:12".to_owned());
@@ -145,19 +145,19 @@ mod tests {
     fn display_with_format() {
         let mut fmt = DateFormatter::new();
 
-        fmt.set_weekday(Weekday::Mon);
+        fmt.set_weekday(Weekday::Monday);
         let f = String::from("%w");
         assert_eq!(fmt.with_format(f), "Mon".to_string());
 
-        fmt.set_weekday(Weekday::Sat);
+        fmt.set_weekday(Weekday::Saturday);
         let f = String::from("%W");
         assert_eq!(fmt.with_format(f), "Saturday".to_string());
 
-        fmt.set_month(6);
+        fmt.set_month(time::Month::June);
         let f = String::from("%m");
         assert_eq!(fmt.with_format(f), "Jun".to_string());
 
-        fmt.set_month(7);
+        fmt.set_month(time::Month::July);
         let f = String::from("%M");
         assert_eq!(fmt.with_format(f), "July".to_string());
 
@@ -165,26 +165,30 @@ mod tests {
         let f = String::from("%d");
         assert_eq!(fmt.with_format(f), "12".to_string());
 
+        fmt.set_hour(12);
+        fmt.set_minute(20);
+        let f = String::from("%HH:%MM %P");
+        assert_eq!(fmt.with_format(f), "12:20 AM".to_string());
+
+        fmt.set_hour(23);
+        fmt.set_minute(20);
+        let f = String::from("%HH:%MM %P");
+        assert_eq!(fmt.with_format(f), "11:20 PM".to_string());
+
+        fmt.set_railway(true);
         fmt.set_hour(20);
         fmt.set_minute(20);
         let f = String::from("%HH:%MM");
         assert_eq!(fmt.with_format(f), "20:20".to_string());
-
-        fmt.set_hour(12);
-        fmt.set_minute(20);
-        fmt.set_meridiem(false);
-        let f = String::from("%HH:%MM %P");
-        assert_eq!(fmt.with_format(f), "12:20 AM".to_string());
     }
 
     #[test]
     fn pick_icon() {
         let mut fmt = DateFormatter::new();
-        fmt.set_weekday(Weekday::Sun);
-        fmt.set_meridiem(true);
+        fmt.set_weekday(Weekday::Sunday);
         fmt.set_day(1);
-        fmt.set_month(8);
-        fmt.set_hour(2);
+        fmt.set_month(time::Month::August);
+        fmt.set_hour(14);
         fmt.set_minute(37);
         assert_eq!(fmt.set_icon(), "weather-clear-symbolic");
     }
