@@ -12,5 +12,9 @@ pub mod network;
 pub mod uptime;
 
 pub trait Iconize {
-    fn set_icon(&self, icon: &mut crate::Icon);
+    fn set_icon(&self) -> &str;
+}
+
+pub trait Format {
+    fn with_format(&self, format: String) -> String;
 }
