@@ -1,5 +1,4 @@
-use super::Iconize;
-use crate::Icon;
+use super::{Format, Iconize};
 use bytesize::ByteSize;
 use std::fmt;
 
@@ -7,7 +6,6 @@ pub struct NetworkFormatter {
     logical_address: Option<String>,
     rx_bytes: Option<usize>,
     tx_bytes: Option<usize>,
-    format: Option<String>,
 }
 
 impl NetworkFormatter {
@@ -16,7 +14,6 @@ impl NetworkFormatter {
             logical_address: None,
             rx_bytes: None,
             tx_bytes: None,
-            format: None,
         }
     }
 
@@ -43,38 +40,40 @@ impl NetworkFormatter {
     pub fn get_tx_bytes(&self) -> Option<ByteSize> {
         self.tx_bytes.map(|bytes| ByteSize::kb(bytes as u64 / 1024))
     }
+}
 
-    pub fn from_config(&mut self, format: String) {
-        if let (Some(addr), Some(rx_b), Some(tx_b)) = (
-            self.get_logical_address(),
-            self.get_rx_bytes(),
-            self.get_tx_bytes(),
-        ) {
-            self.format = Some(
-                format
-                    .replace("%a", &addr)
-                    .replace("%t", &tx_b.to_string())
-                    .replace("%r", &rx_b.to_string()),
-            )
+impl Iconize for NetworkFormatter {
+    fn set_icon(&self) -> &str {
+        match self.logical_address {
+            Some(_) => "network-wireless-symbolic",
+            _ => "network-wireless-disconnected-symbolic",
         }
     }
 }
 
-impl Iconize for NetworkFormatter {
-    fn set_icon(&self, icon: &mut Icon) {
+impl Format for NetworkFormatter {
+    fn with_format(&self, mut format: String) -> String {
         match self.get_logical_address() {
-            Some(_) => icon.find_icon("network-wireless-symbolic"),
-            _ => icon.find_icon("network-wireless-disconnected-symbolic"),
+            Some(addr) => format = format.replace("%a", &addr),
+            _ => format = format.replace("%a", ""),
         }
+
+        match self.get_rx_bytes() {
+            Some(bytes) => format = format.replace("%r", &bytes.to_string()),
+            _ => format = format.replace("%r", ""),
+        }
+
+        match self.get_tx_bytes() {
+            Some(bytes) => format = format.replace("%t", &bytes.to_string()),
+            _ => format = format.replace("%t", ""),
+        }
+
+        format
     }
 }
 
 impl fmt::Display for NetworkFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        if let Some(format) = &self.format {
-            return writeln!(f, "{}", format);
-        }
-
         if let Some(addr) = &self.get_logical_address() {
             writeln!(f, "Local IP: {}", addr);
         }
@@ -91,7 +90,7 @@ mod tests {
     use super::*;
 
     #[test]
-    fn display_network() {
+    fn display() {
         let mut fmt = NetworkFormatter::new();
 
         fmt.set_logical_address("127.0.0.1".to_owned());
@@ -105,4 +104,25 @@ mod tests {
             "Local IP: 192.168.1.1\nData: 700.0 KB 🠗 / 700.0 KB 🠕".to_owned()
         );
     }
+
+    #[test]
+    fn display_with_format() {
+        let mut fmt = NetworkFormatter::new();
+        fmt.set_rx_bytes(717000);
+        let f = String::from("%r");
+        assert_eq!(fmt.with_format(f), "700.0 KB");
+
+        fmt.set_logical_address("192.168.1.1".to_owned());
+        fmt.set_tx_bytes(717000);
+        let f = String::from("%a, %r, %t");
+        assert_eq!(fmt.with_format(f), "192.168.1.1, 700.0 KB, 700.0 KB");
+    }
+
+    #[test]
+    fn pick_icon() {
+        let mut fmt = NetworkFormatter::new();
+        assert_eq!(fmt.set_icon(), "network-wireless-disconnected-symbolic");
+        fmt.set_logical_address("192.168.1.1".to_string());
+        assert_eq!(fmt.set_icon(), "network-wireless-symbolic");
+    }
 }
