@@ -1,6 +1,5 @@
-use crate::options::Command;
-use crate::Config;
-use crate::Icon;
+use crate::options::Subcommand;
+use std::path::PathBuf;
 
 use libmacchina::traits::ReadoutError;
 use notify_rust::Notification;
@@ -10,55 +9,26 @@ use std::fmt;
 
 pub struct Notifier {
     /// The header of a notification.
-    title: Title,
+    pub title: Title,
     /// The body of a notification.
-    body: String,
+    pub body: String,
+    /// The path to an icon.
+    pub icon: PathBuf,
     /// The timeout of a notification.
-    timeout: u32,
-    /// A path to an icon as a string.
-    icon: String,
+    pub timeout: u32,
 }
 
+#[allow(clippy::new_without_default)]
 impl Notifier {
     pub fn new() -> Notifier {
         Notifier {
             title: Title::Date,
             timeout: 5,
-            icon: String::new(),
+            icon: PathBuf::new(),
             body: String::new(),
         }
     }
 
-    pub fn set_title(&mut self, title: Title) {
-        self.title = title;
-    }
-
-    pub fn get_title(&self) -> String {
-        self.title.to_string()
-    }
-
-    pub fn set_icon(&mut self, icon: Icon) {
-        let path = icon.get_path();
-
-        if !path.exists() {
-            return;
-        }
-
-        if let Some(str) = path.to_str() {
-            self.icon = str.to_string();
-        }
-    }
-
-    pub fn set_timeout(&mut self, config: Config) {
-        if let Some(timeout) = config.get_timeout() {
-            self.timeout = timeout;
-        }
-    }
-
-    pub fn get_timeout(&self) -> Timeout {
-        Timeout::Milliseconds(self.timeout * 1000)
-    }
-
     pub fn set_body(&mut self, body: Result<String, ReadoutError>) {
         match body {
             Ok(b) => self.body = b,
@@ -66,18 +36,14 @@ impl Notifier {
         }
     }
 
-    pub fn get_body(&self) -> String {
-        self.body.to_owned()
-    }
-
     pub fn send(&self) {
         Notification::new()
-            .body(&self.get_body())
-            .summary(&self.get_title())
-            .timeout(self.get_timeout())
-            .icon(&self.icon)
+            .body(&self.body)
+            .summary(&self.title.to_string())
+            .timeout(Timeout::Milliseconds(self.timeout * 1000))
+            .icon(&self.icon.to_string_lossy())
             .show()
-            .expect("Verify that a notification daemon is running in the background");
+            .expect("No notification daemon running.");
     }
 }
 
@@ -106,15 +72,15 @@ impl fmt::Display for Title {
     }
 }
 
-impl From<&Command> for Title {
-    fn from(cmd: &Command) -> Self {
+impl From<&Subcommand> for Title {
+    fn from(cmd: &Subcommand) -> Self {
         match cmd {
-            Command::Date => Title::Date,
-            Command::Uptime => Title::Uptime,
-            Command::Memory => Title::Memory,
-            Command::Battery => Title::Battery,
-            Command::Network => Title::Network,
-            Command::Backlight => Title::Backlight,
+            Subcommand::Date => Title::Date,
+            Subcommand::Uptime => Title::Uptime,
+            Subcommand::Memory => Title::Memory,
+            Subcommand::Battery => Title::Battery,
+            Subcommand::Network => Title::Network,
+            Subcommand::Backlight => Title::Backlight,
         }
     }
 }
