@@ -10,14 +10,14 @@ use crate::fmt::memory::MemoryFormatter;
 use crate::fmt::network::NetworkFormatter;
 use crate::fmt::uptime::UptimeFormatter;
 use crate::fmt::{Format, Iconize};
-use crate::helpers;
-use chrono::{Datelike, Timelike};
 use libmacchina::traits::BatteryReadout as _;
 use libmacchina::traits::GeneralReadout as _;
 use libmacchina::traits::MemoryReadout as _;
 use libmacchina::traits::NetworkReadout as _;
 use libmacchina::traits::ReadoutError;
 use libmacchina::{BatteryReadout, GeneralReadout, MemoryReadout, NetworkReadout};
+use time::OffsetDateTime;
+use time::UtcOffset;
 
 pub fn uptime(icon: (&mut String, bool)) -> Result<String, ReadoutError> {
     let readout = GeneralReadout::new();
@@ -127,24 +127,24 @@ pub fn backlight(icon: (&mut String, bool)) -> Result<String, ReadoutError> {
 
 pub fn date(config: &Config, icon: (&mut String, bool)) -> Result<String, ReadoutError> {
     let mut fmt = DateFormatter::new();
-    if let Some(readout) = helpers::utc_from_timezone() {
-        let hour = readout.hour12();
-        fmt.set_weekday(readout.weekday());
-        fmt.set_month(readout.month());
-        fmt.set_day(readout.day());
-        fmt.set_minute(readout.minute());
-        fmt.set_meridiem(hour.0);
-        fmt.set_hour(hour.1);
+    if let Ok(local_offset) = UtcOffset::current_local_offset() {
+        let datetime = OffsetDateTime::now_utc().to_offset(local_offset);
+
+        if let Some(date) = &config.date {
+            fmt.set_railway(date.is_railway());
+        }
+
+        fmt.set_weekday(datetime.weekday());
+        fmt.set_month(datetime.month());
+        fmt.set_day(datetime.day());
+        fmt.set_minute(datetime.minute());
+        fmt.set_hour(datetime.hour());
 
         if icon.1 {
             icon.0.push_str(fmt.set_icon());
         }
 
         if let Some(date) = &config.date {
-            if date.is_railway() {
-                fmt.set_hour(readout.hour());
-            }
-
             if let Some(format) = &date.format {
                 return Ok(fmt.with_format(format.to_owned()));
             }
